@@ -1,8 +1,7 @@
-"""Internal :term:`type annotations <annotation>`
+"""Internal :term:`type annotations <annotation>`.
 
 Notes
 -----
-
 :class:`StrPath` and :class:`StrOrBytesPath` is based on `typeshed's`_.
 
 .. _typeshed's: https://github.com/python/typeshed/blob/5df8de7/stdlib/_typeshed/__init__.pyi#L115-L118
