@@ -1,3 +1,4 @@
+"""Run hg commands directly against a local git repo."""
 import datetime
 import pathlib
 import shlex
@@ -11,6 +12,8 @@ _CMD = Union[StrOrBytesPath, Sequence[StrOrBytesPath]]
 
 
 class Git:
+    """Run commands directly on a git repository."""
+
     progress_callback: Optional[ProgressCallbackProtocol] = None
 
     # Sub-commands
@@ -71,6 +74,7 @@ class Git:
         self.stash = GitStashCmd(dir=self.dir, cmd=self)
 
     def __repr__(self) -> str:
+        """Representation of Git repo command object."""
         return f"<Git dir={self.dir}>"
 
     def run(
@@ -104,7 +108,8 @@ class Git:
         log_in_real_time: bool = False,
         **kwargs: Any,
     ) -> str:
-        """
+        """Run a command for this git repository.
+
         Passing None to a subcommand option, the flag won't be passed unless otherwise
         stated.
 
@@ -167,11 +172,7 @@ class Git:
         >>> git.run(['help'])
         "usage: git [...--version] [...--help] [-C <path>]..."
         """
-
-        if isinstance(args, Sequence):
-            cli_args = ["git", *args]
-        else:
-            cli_args = ["git", args]
+        cli_args = ["git", *args] if isinstance(args, Sequence) else ["git", args]
 
         if "cwd" not in kwargs:
             kwargs["cwd"] = self.dir
@@ -1318,8 +1319,9 @@ class Git:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """Switches branches or checks out files. Wraps
-        `git checkout <https://git-scm.com/docs/git-checkout>`_ (`git co`).
+        """Switch branches or checks out files.
+
+        Wraps `git checkout <https://git-scm.com/docs/git-checkout>`_ (`git co`).
 
         Parameters
         ----------
@@ -1442,8 +1444,9 @@ class Git:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """Status of working tree. Wraps
-        `git status <https://git-scm.com/docs/git-status>`_.
+        """Return status of working tree.
+
+        Wraps `git status <https://git-scm.com/docs/git-status>`_.
 
         `git ls-files` has similar params (e.g. `z`)
 
@@ -1589,10 +1592,9 @@ class Git:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """Status of working tree. Wraps
-        `git status <https://git-scm.com/docs/git-status>`_.
+        """Get and set repo configuration.
 
-        `git ls-files` has similar params (e.g. `z`)
+        `git config <https://git-scm.com/docs/git-config>`_.
 
         Parameters
         ----------
@@ -1963,9 +1965,8 @@ class Git:
             (max_age, "--max-age"),
             (min_age, "--min-age"),
         ]:
-            if datetime_kwarg is not None:
-                if isinstance(datetime, str):
-                    local_flags.extend([datetime_shell_flag, datetime_kwarg])
+            if datetime_kwarg is not None and isinstance(datetime, str):
+                local_flags.extend([datetime_shell_flag, datetime_kwarg])
 
         for int_flag, int_shell_flag in [
             (max_count, "--max-count"),
@@ -2043,8 +2044,9 @@ class Git:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """symbolic-ref. Wraps `git symbolic-ref
-        <https://git-scm.com/docs/symbolic-ref>`_.
+        """Return symbolic-ref.
+
+        Wraps `git symbolic-ref <https://git-scm.com/docs/symbolic-ref>`_.
 
         Examples
         --------
@@ -2167,6 +2169,8 @@ GitSubmoduleCmdCommandLiteral = Literal[
 
 
 class GitSubmoduleCmd:
+    """Run submodule commands in a git repository."""
+
     def __init__(self, *, dir: StrPath, cmd: Optional[Git] = None) -> None:
         """Lite, typed, pythonic wrapper for git-submodule(1).
 
@@ -2196,6 +2200,7 @@ class GitSubmoduleCmd:
         self.cmd = cmd if isinstance(cmd, Git) else Git(dir=self.dir)
 
     def __repr__(self) -> str:
+        """Representation of a git submodule command object."""
         return f"<GitSubmoduleCmd dir={self.dir}>"
 
     def run(
@@ -2210,7 +2215,9 @@ class GitSubmoduleCmd:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """Wraps `git submodule <https://git-scm.com/docs/git-submodule>`_.
+        """Run a command against a git submodule.
+
+        Wraps `git submodule <https://git-scm.com/docs/git-submodule>`_.
 
         Examples
         --------
@@ -2240,7 +2247,7 @@ class GitSubmoduleCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git submodule init
+        """Git submodule init.
 
         Examples
         --------
@@ -2257,7 +2264,7 @@ class GitSubmoduleCmd:
 
         return self.run(
             "init",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=[*local_flags, "--", *required_flags],
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2277,7 +2284,7 @@ class GitSubmoduleCmd:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """git submodule update
+        """Git submodule update.
 
         Examples
         --------
@@ -2320,7 +2327,7 @@ class GitSubmoduleCmd:
 
         return self.run(
             "update",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=[*local_flags, "--", *required_flags],
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2344,6 +2351,8 @@ GitRemoteCommandLiteral = Literal[
 
 
 class GitRemoteCmd:
+    """Run commands directly for a git remote on a git repository."""
+
     def __init__(self, *, dir: StrPath, cmd: Optional[Git] = None) -> None:
         r"""Lite, typed, pythonic wrapper for git-remote(1).
 
@@ -2373,6 +2382,7 @@ class GitRemoteCmd:
         self.cmd = cmd if isinstance(cmd, Git) else Git(dir=self.dir)
 
     def __repr__(self) -> str:
+        """Representation of a git remote for a git repository."""
         return f"<GitRemoteCmd dir={self.dir}>"
 
     def run(
@@ -2386,7 +2396,9 @@ class GitRemoteCmd:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        r"""Wraps `git remote <https://git-scm.com/docs/git-remote>`_.
+        r"""Run command against a git remote.
+
+        Wraps `git remote <https://git-scm.com/docs/git-remote>`_.
 
         Examples
         --------
@@ -2421,7 +2433,7 @@ class GitRemoteCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git remote add
+        """Git remote add.
 
         Examples
         --------
@@ -2442,7 +2454,7 @@ class GitRemoteCmd:
                 local_flags.append("--mirror")
         return self.run(
             "add",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=[*local_flags, "--", *required_flags],
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2457,7 +2469,7 @@ class GitRemoteCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git remote rename
+        """Git remote rename.
 
         Examples
         --------
@@ -2490,7 +2502,7 @@ class GitRemoteCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git remote remove
+        """Git remote remove.
 
         Examples
         --------
@@ -2519,7 +2531,7 @@ class GitRemoteCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git remote show
+        """Git remote show.
 
         Examples
         --------
@@ -2540,7 +2552,7 @@ class GitRemoteCmd:
 
         return self.run(
             "show",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=[*local_flags, "--", *required_flags],
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2554,7 +2566,7 @@ class GitRemoteCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git remote prune
+        """Git remote prune.
 
         Examples
         --------
@@ -2573,7 +2585,7 @@ class GitRemoteCmd:
 
         return self.run(
             "prune",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=[*local_flags, "--", *required_flags],
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2588,7 +2600,7 @@ class GitRemoteCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git remote get-url
+        """Git remote get-url.
 
         Examples
         --------
@@ -2612,7 +2624,7 @@ class GitRemoteCmd:
 
         return self.run(
             "get-url",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=[*local_flags, "--", *required_flags],
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2630,7 +2642,7 @@ class GitRemoteCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git remote set-url
+        """Git remote set-url.
 
         Examples
         --------
@@ -2678,7 +2690,7 @@ class GitRemoteCmd:
 
         return self.run(
             "set-url",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=[*local_flags, "--", *required_flags],
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2700,6 +2712,8 @@ GitStashCommandLiteral = Literal[
 
 
 class GitStashCmd:
+    """Run commands directly against a git stash storage for a git repo."""
+
     def __init__(self, *, dir: StrPath, cmd: Optional[Git] = None) -> None:
         """Lite, typed, pythonic wrapper for git-stash(1).
 
@@ -2729,6 +2743,7 @@ class GitStashCmd:
         self.cmd = cmd if isinstance(cmd, Git) else Git(dir=self.dir)
 
     def __repr__(self) -> str:
+        """Representation of git stash storage command object."""
         return f"<GitStashCmd dir={self.dir}>"
 
     def run(
@@ -2743,7 +2758,9 @@ class GitStashCmd:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """Wraps `git stash <https://git-scm.com/docs/git-stash>`_.
+        """Run a command against a git repository's stash storage.
+
+        Wraps `git stash <https://git-scm.com/docs/git-stash>`_.
 
         Examples
         --------
@@ -2772,7 +2789,7 @@ class GitStashCmd:
         log_in_real_time: bool = False,
         check_returncode: Optional[bool] = None,
     ) -> str:
-        """git stash list
+        """Git stash list.
 
         Examples
         --------
@@ -2796,7 +2813,7 @@ class GitStashCmd:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """git stash update
+        """Git stash update.
 
         TODO: Fill-in
 
@@ -2823,7 +2840,7 @@ class GitStashCmd:
 
         return self.run(
             "push",
-            local_flags=local_flags + ["--"] + required_flags,
+            local_flags=[*local_flags, "--", *required_flags],
             check_returncode=check_returncode,
             log_in_real_time=log_in_real_time,
         )
@@ -2839,7 +2856,7 @@ class GitStashCmd:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """git stash pop
+        """Git stash pop.
 
         Examples
         --------
@@ -2891,7 +2908,7 @@ class GitStashCmd:
         check_returncode: Optional[bool] = None,
         **kwargs: Any,
     ) -> str:
-        """git stash save
+        """Git stash save.
 
         Examples
         --------
